@@ -22,11 +22,11 @@ __email__                       = "perry@hardconsulting.com"
 __copyright__                   = "Copyright (c) 2013 Hard Consulting Corporation"
 __license__                     = "Dual License: GPLv3 (or later) and Commercial (see LICENSE)"
 
-__all__                         = ["automata", "dotdict", "greenery", "misc"]
+__all__                         = ["automata", "dotdict", "misc"]
 
 # These modules form the public interface of cpppo; always load them into the
 # main cpppo namespace
+from .version  import __version__
 from .automata import *
 from .dotdict  import *
 from .misc     import *
-from .misc     import __version__
